@@ -8,7 +8,7 @@ use Scalar::Util qw(refaddr blessed weaken);
 use Carp;
 use Try::Tiny ();
 
-our $VERSION = '0.100';
+our $VERSION = '0.110';
 
 our @CARP_NOT = qw(Try::Tiny Future);
 
@@ -615,6 +615,9 @@ if C<$future> is rejected and DESTROYed.
 
 Alias of C<< $future->then(undef, $on_rejected) >>.
 
+B<Note:> The superclass L<Future> has its own C<catch> method since version 0.33.
+L<Future>'s C<catch> method is different from L<Future::Q>'s, and L<Future::Q> overrides it.
+
 =head2 $next_future = $future->finally($callback)
 
 Registers a callback function that is executed when C<$future> is either fulfilled or rejected.
@@ -931,7 +934,7 @@ Subclass of L<Future> that works well with L<IO::Async> event framework.
 
 Another promise/deferred/future/whatever implementation.
 Its goal is to implement Promises/A+ specification.
-Because Q is also an implementation of Promises/A+, L<Promises> and Q (and L<Futuer::Q>) are very similar.
+Because Q is also an implementation of Promises/A+, L<Promises> and Q (and L<Future::Q>) are very similar.
 
 
 =item L<AnyEvent::Promises>
